==> cdk-ec2spot-0.0.55.tar.gz: package/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file. See [standard-version](https://github.com/conventional-changelog/standard-version) for commit guidelines.

### [0.0.37](https://github.com/pahud/cdk-ec2spot/compare/v0.0.36...v0.0.37) (2021-02-23)

### [0.0.36](https://github.com/pahud/cdk-ec2spot/compare/v0.0.35...v0.0.36) (2021-02-23)

### [0.0.35](https://github.com/pahud/cdk-ec2spot/compare/v0.0.34...v0.0.35) (2021-02-19)


### Features

* add spot instance support ([9c3d182](https://github.com/pahud/cdk-ec2spot/commit/9c3d182418660aa1245de760d9aaff6102da9718))
* spotfleet support ([7e29883](https://github.com/pahud/cdk-ec2spot/commit/7e29883c8cbbd2dc67c8a196e2ac004c5a9e731c))

### [0.0.34](https://github.com/pahud/cdk-ec2spot/compare/v0.0.33...v0.0.34) (2021-02-19)


### Features

* Spot instance support ([#49](https://github.com/pahud/cdk-ec2spot/issues/49)) ([d2f83af](https://github.com/pahud/cdk-ec2spot/commit/d2f83af51585dc46df9385ade3cbe5e30e48b925))

### [0.0.33](https://github.com/pahud/cdk-ec2spot/compare/v0.0.32...v0.0.33) (2021-02-18)

### [0.0.32](https://github.com/pahud/cdk-ec2spot/compare/v0.0.31...v0.0.32) (2021-02-17)

### [0.0.31](https://github.com/pahud/cdk-ec2spot/compare/v0.0.30...v0.0.31) (2021-02-16)

### [0.0.30](https://github.com/pahud/cdk-ec2spot/compare/v0.0.29...v0.0.30) (2021-02-15)

### [0.0.29](https://github.com/pahud/cdk-ec2spot/compare/v0.0.28...v0.0.29) (2021-02-14)

### [0.0.28](https://github.com/pahud/cdk-ec2spot/compare/v0.0.27...v0.0.28) (2021-02-13)

### [0.0.27](https://github.com/pahud/cdk-ec2spot/compare/v0.0.26...v0.0.27) (2021-02-12)

### [0.0.26](https://github.com/pahud/cdk-ec2spot/compare/v0.0.25...v0.0.26) (2021-02-11)

### [0.0.25](https://github.com/pahud/cdk-ec2spot/compare/v0.0.24...v0.0.25) (2021-02-11)

### [0.0.24](https://github.com/pahud/cdk-ec2spot/compare/v0.0.23...v0.0.24) (2021-02-10)

### [0.0.23](https://github.com/pahud/cdk-ec2spot/compare/v0.0.22...v0.0.23) (2021-02-09)

### [0.0.22](https://github.com/pahud/cdk-ec2spot/compare/v0.0.21...v0.0.22) (2021-02-08)

### [0.0.21](https://github.com/pahud/cdk-ec2spot/compare/v0.0.20...v0.0.21) (2021-02-07)

### [0.0.20](https://github.com/pahud/cdk-ec2spot/compare/v0.0.19...v0.0.20) (2021-02-06)

### [0.0.19](https://github.com/pahud/cdk-ec2spot/compare/v0.0.18...v0.0.19) (2021-02-05)

### [0.0.18](https://github.com/pahud/cdk-ec2spot/compare/v0.0.17...v0.0.18) (2021-02-04)

### [0.0.17](https://github.com/pahud/cdk-ec2spot/compare/v0.0.16...v0.0.17) (2021-02-04)

### [0.0.16](https://github.com/pahud/cdk-ec2spot/compare/v0.0.15...v0.0.16) (2021-02-03)

### [0.0.15](https://github.com/pahud/cdk-ec2spot/compare/v0.0.14...v0.0.15) (2021-02-02)


### Features

* spotfleet support ([#20](https://github.com/pahud/cdk-ec2spot/issues/20)) ([7e0f7b7](https://github.com/pahud/cdk-ec2spot/commit/7e0f7b7e3f6dcde4636b970cd0d4b2f53231f6aa)), closes [#19](https://github.com/pahud/cdk-ec2spot/issues/19)

### [0.0.14](https://github.com/pahud/cdk-ec2spot/compare/v0.0.13...v0.0.14) (2021-02-02)

### [0.0.13](https://github.com/pahud/cdk-ec2spot/compare/v0.0.12...v0.0.13) (2021-02-01)

### [0.0.12](https://github.com/pahud/cdk-ec2spot/compare/v0.0.11...v0.0.12) (2021-02-01)

### [0.0.11](https://github.com/pahud/cdk-ec2spot/compare/v0.0.10...v0.0.11) (2021-01-30)

### [0.0.10](https://github.com/pahud/cdk-ec2spot/compare/v0.0.9...v0.0.10) (2021-01-29)

### [0.0.9](https://github.com/pahud/cdk-ec2spot/compare/v0.0.8...v0.0.9) (2021-01-28)

### [0.0.8](https://github.com/pahud/cdk-ec2spot/compare/v0.0.7...v0.0.8) (2021-01-27)

### [0.0.7](https://github.com/pahud/cdk-ec2spot/compare/v0.0.6...v0.0.7) (2021-01-26)

### [0.0.6](https://github.com/pahud/cdk-ec2spot/compare/v0.0.5...v0.0.6) (2021-01-25)

### [0.0.5](https://github.com/pahud/cdk-ec2spot/compare/v0.0.4...v0.0.5) (2021-01-23)

### [0.0.4](https://github.com/pahud/cdk-ec2spot/compare/v0.0.3...v0.0.4) (2021-01-22)

### [0.0.3](https://github.com/pahud/cdk-ec2spot/compare/v0.0.2...v0.0.3) (2021-01-21)

### [0.0.2](https://github.com/pahud/cdk-ec2spot/compare/v0.0.1...v0.0.2) (2021-01-20)

### 0.0.1 (2021-01-20)

==> cdk-ec2spot-2.0.292.tar.gz: package/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file. See [standard-version](https://github.com/conventional-changelog/standard-version) for commit guidelines.

### [0.1.1](https://github.com/pahud/cdk-ec2spot/compare/v0.0.68...v0.1.1) (2021-07-06)

## [0.1.0](https://github.com/pahud/cdk-ec2spot/compare/v0.0.68...v0.1.0) (2021-07-06)

### [0.0.37](https://github.com/pahud/cdk-ec2spot/compare/v0.0.36...v0.0.37) (2021-02-23)

### [0.0.36](https://github.com/pahud/cdk-ec2spot/compare/v0.0.35...v0.0.36) (2021-02-23)

### [0.0.35](https://github.com/pahud/cdk-ec2spot/compare/v0.0.34...v0.0.35) (2021-02-19)


### Features

* add spot instance support ([9c3d182](https://github.com/pahud/cdk-ec2spot/commit/9c3d182418660aa1245de760d9aaff6102da9718))
* spotfleet support ([7e29883](https://github.com/pahud/cdk-ec2spot/commit/7e29883c8cbbd2dc67c8a196e2ac004c5a9e731c))

### [0.0.34](https://github.com/pahud/cdk-ec2spot/compare/v0.0.33...v0.0.34) (2021-02-19)


### Features

* Spot instance support ([#49](https://github.com/pahud/cdk-ec2spot/issues/49)) ([d2f83af](https://github.com/pahud/cdk-ec2spot/commit/d2f83af51585dc46df9385ade3cbe5e30e48b925))

### [0.0.33](https://github.com/pahud/cdk-ec2spot/compare/v0.0.32...v0.0.33) (2021-02-18)

### [0.0.32](https://github.com/pahud/cdk-ec2spot/compare/v0.0.31...v0.0.32) (2021-02-17)

### [0.0.31](https://github.com/pahud/cdk-ec2spot/compare/v0.0.30...v0.0.31) (2021-02-16)

### [0.0.30](https://github.com/pahud/cdk-ec2spot/compare/v0.0.29...v0.0.30) (2021-02-15)

### [0.0.29](https://github.com/pahud/cdk-ec2spot/compare/v0.0.28...v0.0.29) (2021-02-14)

### [0.0.28](https://github.com/pahud/cdk-ec2spot/compare/v0.0.27...v0.0.28) (2021-02-13)

### [0.0.27](https://github.com/pahud/cdk-ec2spot/compare/v0.0.26...v0.0.27) (2021-02-12)

### [0.0.26](https://github.com/pahud/cdk-ec2spot/compare/v0.0.25...v0.0.26) (2021-02-11)

### [0.0.25](https://github.com/pahud/cdk-ec2spot/compare/v0.0.24...v0.0.25) (2021-02-11)

### [0.0.24](https://github.com/pahud/cdk-ec2spot/compare/v0.0.23...v0.0.24) (2021-02-10)

### [0.0.23](https://github.com/pahud/cdk-ec2spot/compare/v0.0.22...v0.0.23) (2021-02-09)

### [0.0.22](https://github.com/pahud/cdk-ec2spot/compare/v0.0.21...v0.0.22) (2021-02-08)

### [0.0.21](https://github.com/pahud/cdk-ec2spot/compare/v0.0.20...v0.0.21) (2021-02-07)

### [0.0.20](https://github.com/pahud/cdk-ec2spot/compare/v0.0.19...v0.0.20) (2021-02-06)

### [0.0.19](https://github.com/pahud/cdk-ec2spot/compare/v0.0.18...v0.0.19) (2021-02-05)

### [0.0.18](https://github.com/pahud/cdk-ec2spot/compare/v0.0.17...v0.0.18) (2021-02-04)

### [0.0.17](https://github.com/pahud/cdk-ec2spot/compare/v0.0.16...v0.0.17) (2021-02-04)

### [0.0.16](https://github.com/pahud/cdk-ec2spot/compare/v0.0.15...v0.0.16) (2021-02-03)

### [0.0.15](https://github.com/pahud/cdk-ec2spot/compare/v0.0.14...v0.0.15) (2021-02-02)


### Features

* spotfleet support ([#20](https://github.com/pahud/cdk-ec2spot/issues/20)) ([7e0f7b7](https://github.com/pahud/cdk-ec2spot/commit/7e0f7b7e3f6dcde4636b970cd0d4b2f53231f6aa)), closes [#19](https://github.com/pahud/cdk-ec2spot/issues/19)

### [0.0.14](https://github.com/pahud/cdk-ec2spot/compare/v0.0.13...v0.0.14) (2021-02-02)

### [0.0.13](https://github.com/pahud/cdk-ec2spot/compare/v0.0.12...v0.0.13) (2021-02-01)

### [0.0.12](https://github.com/pahud/cdk-ec2spot/compare/v0.0.11...v0.0.12) (2021-02-01)

### [0.0.11](https://github.com/pahud/cdk-ec2spot/compare/v0.0.10...v0.0.11) (2021-01-30)

### [0.0.10](https://github.com/pahud/cdk-ec2spot/compare/v0.0.9...v0.0.10) (2021-01-29)

### [0.0.9](https://github.com/pahud/cdk-ec2spot/compare/v0.0.8...v0.0.9) (2021-01-28)

### [0.0.8](https://github.com/pahud/cdk-ec2spot/compare/v0.0.7...v0.0.8) (2021-01-27)

### [0.0.7](https://github.com/pahud/cdk-ec2spot/compare/v0.0.6...v0.0.7) (2021-01-26)

### [0.0.6](https://github.com/pahud/cdk-ec2spot/compare/v0.0.5...v0.0.6) (2021-01-25)

### [0.0.5](https://github.com/pahud/cdk-ec2spot/compare/v0.0.4...v0.0.5) (2021-01-23)

### [0.0.4](https://github.com/pahud/cdk-ec2spot/compare/v0.0.3...v0.0.4) (2021-01-22)

### [0.0.3](https://github.com/pahud/cdk-ec2spot/compare/v0.0.2...v0.0.3) (2021-01-21)

### [0.0.2](https://github.com/pahud/cdk-ec2spot/compare/v0.0.1...v0.0.2) (2021-01-20)

### 0.0.1 (2021-01-20)
